stravalib.unithelper.Quantity
=============================

.. currentmodule:: stravalib.unithelper

.. autoclass:: Quantity


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~Quantity.__init__





   .. rubric:: Attributes

   .. autosummary::

      ~Quantity.num
      ~Quantity.unit
